summaryrefslogtreecommitdiff
path: root/kms++util/src
diff options
context:
space:
mode:
authorTomi Valkeinen <tomi.valkeinen@ideasonboard.com>2026-05-07 22:18:39 +0300
committerTomi Valkeinen <tomi.valkeinen@ideasonboard.com>2026-05-08 11:57:30 +0300
commit9cb56229bcd96448ae133c5b42622e1c1e740197 (patch)
tree881f2b2070c7b046ca3e79b7b22589d4826eea79 /kms++util/src
parentc5dc30f1d6ce98bdc28381cc75650eab0e98ce96 (diff)
kms++: Update pixel formats to latest upstream
Diffstat (limited to 'kms++util/src')
-rw-r--r--kms++util/src/conv-gray.h2
-rw-r--r--kms++util/src/conv-yuv-planar-packed.h4
-rw-r--r--kms++util/src/conv-yuv-semiplanar.h6
-rw-r--r--kms++util/src/testpat.cpp8
4 files changed, 10 insertions, 10 deletions
diff --git a/kms++util/src/conv-gray.h b/kms++util/src/conv-gray.h
index fed8c5c..7fead46 100644
--- a/kms++util/src/conv-gray.h
+++ b/kms++util/src/conv-gray.h
@@ -28,7 +28,7 @@ using Y12_Layout = FormatLayout<PlaneLayout<uint16_t,
using Y16_Layout = FormatLayout<PlaneLayout<uint16_t,
ComponentLayout<ComponentType::Y, 16, 0>>>;
-using Y10_P32_Layout = FormatLayout<PlaneLayout<uint32_t,
+using XYYY2101010_Layout = FormatLayout<PlaneLayout<uint32_t,
ComponentLayout<ComponentType::Y, 10, 0>, // Y0
ComponentLayout<ComponentType::Y, 10, 10>, // Y1
ComponentLayout<ComponentType::Y, 10, 20>, // Y2
diff --git a/kms++util/src/conv-yuv-semiplanar.h b/kms++util/src/conv-yuv-semiplanar.h
index f9d771d..81117c1 100644
--- a/kms++util/src/conv-yuv-semiplanar.h
+++ b/kms++util/src/conv-yuv-semiplanar.h
@@ -35,7 +35,7 @@ using NV16_Layout = NV12_Family_Layout<ComponentType::Cb, ComponentType::Cr, 2,
using NV61_Layout = NV12_Family_Layout<ComponentType::Cr, ComponentType::Cb, 2, 1>;
template<size_t HSub, size_t VSub>
-struct XV15_Family_Layout
+struct P030_Family_Layout
: public FormatLayout<
PlaneLayout<uint32_t,
ComponentLayout<ComponentType::Y, 10, 0>,
@@ -56,8 +56,8 @@ struct XV15_Family_Layout
static constexpr size_t v_sub = VSub;
};
-using XV15_Layout = XV15_Family_Layout<2, 2>;
-using XV20_Layout = XV15_Family_Layout<2, 1>;
+using P030_Layout = P030_Family_Layout<2, 2>;
+using P230_Layout = P030_Family_Layout<2, 1>;
template<size_t HSub, size_t VSub>
struct SubsampleHelper {
diff --git a/kms++util/src/testpat.cpp b/kms++util/src/testpat.cpp
index e424103..b9f1e56 100644
--- a/kms++util/src/testpat.cpp
+++ b/kms++util/src/testpat.cpp
@@ -379,8 +379,8 @@ static void draw_test_pattern_part(IFramebuffer& fb, size_t start_y, size_t end_
break;
switch (fb.format()) {
- CASE_YUV_SEMI(XV20);
- CASE_YUV_SEMI(XV15);
+ CASE_YUV_SEMI(P230);
+ CASE_YUV_SEMI(P030);
CASE_YUV_SEMI(NV12);
CASE_YUV_SEMI(NV21);
CASE_YUV_SEMI(NV16);
@@ -429,9 +429,9 @@ static void draw_test_pattern_part(IFramebuffer& fb, size_t start_y, size_t end_
CASE_YUV_PLANAR(YVU420);
CASE_Y_ONLY(Y8);
- CASE_Y_ONLY(Y10_P32);
+ CASE_Y_ONLY(XYYY2101010);
- CASE_YUV_PLANAR_PACKED(X403);
+ CASE_YUV_PLANAR_PACKED(T430);
CASE_RAW(SRGGB8);
CASE_RAW(SGBRG8);
diff --git a/kms++util/src/conv-yuv-planar-packed.h b/kms++util/src/conv-yuv-planar-packed.h
index 4475100..481b594 100644
--- a/kms++util/src/conv-yuv-planar-packed.h
+++ b/kms++util/src/conv-yuv-planar-packed.h
@@ -9,9 +9,9 @@
namespace kms
{
-/* YUV Planar Packed (only X403 for now) */
+/* YUV Planar Packed (only T430 for now) */
-struct X403_Layout : FormatLayout <
+struct T430_Layout : FormatLayout <
PlaneLayout<uint32_t,
ComponentLayout<ComponentType::Y, 10, 0>,
ComponentLayout<ComponentType::Y, 10, 10>,